boofun.core.numba\_optimizations
==================================

.. automodule:: boofun.core.numba_optimizations


   .. rubric:: Functions

   .. autosummary::

      anf_batch_eval
      batch_binary_to_indices
      binary_to_index
      degree_computation
      fallback_fourier_batch
      fallback_influences
      fallback_truth_table_batch
      fourier_batch_eval
      get_numba_stats
      influences_computation
      is_numba_available
      noise_stability_computation
      numba_optimize
      polynomial_batch_eval
      popcount
      truth_table_batch_eval
      walsh_hadamard_transform_inplace

   .. rubric:: Classes

   .. autosummary::

      NumbaOptimizer
